
%-------------------------------------------------------------------------------
%   Computes the hsa sensor data for a spinning spacecraft. This computes
%   the time tags for a single sensor. You should include biases on the
%   cant angle, dihedral angle and earth width. A time delay can also
%   be entered.
%-------------------------------------------------------------------------------
%   Form:
%   [tle,tte,hew,sm] = HSAData(us, un, eradius, spinrate, cant, dihedral,
%                              ua, quant, qtype, onesigma, delay)
%-------------------------------------------------------------------------------
%
%   ------
%   Inputs
%   ------
%   us           (3,n)     Unit sun vectors
%   un           (3,n)     Unit nadir vectors
%   ua           (3,1)     Unit spin axis vector
%   eradius      (n)       Angular radius of the earth
%   spinrate     (1,1)     Spin rate
%   cant         (1,1)     Cant angle (rad)
%   dihedral     (1,1)     Dihedral angle - between sun sensor and HSA (rad)
%   quant        (1,1)     Quantization
%   qtype        (1,1)     Type of quantization-either 'round' or 'truncate'
%   onesigma     (1,1)     One sigma noise (rad)
%   delay        (1,1)     Time delay
%
%   -------
%   Outputs
%   -------
%   tle          (n)       Leading edge times
%   tte          (n)       Trailing edge time
%   hew          (n)       Half chord width (rad)
%   sm           (n)       Dihedral angle (rad)
%
%-------------------------------------------------------------------------------